@@ -64,3 +64,13 @@ class Firestore:
         if (blob_ref.exists()):
             blob_ref.delete()
         return True
+
+    def duplicate_document(self, from_path: str, to_path: str, fileName: str):
+        data = self.firestore_db.collection(from_path).document(fileName).get()
+        if data.exists:
+            self.write_doc(to_path, fileName, data.to_dict())
+
+    def duplicate_collection(self, from_path: str, to_path: str):
+        data = self.get_collection_docs(from_path)
+        for doc in data:
+            self.write_doc(to_path, doc.id, doc.to_dict())
