@@ -1,4 +1,4 @@
 from .auth import validate_key, get_key
-from .variables import NAME
+from .variables import NAME, NAME_ON_PREM
 # from .reservation import ReservationSync
 from .reservation_v2 import ReservationSync
