@@ -35,3 +35,19 @@ def verify_owner_and_get_id(token: dict = Depends(jwtBearer)):
             status_code=status.HTTP_401_UNAUTHORIZED,
             detail="Invalid JWT",
         )
+
+
+def verify_and_get_jwt(token: dict = Depends(jwtBearer)):
+    try:
+        user = auth.verify_id_token(token.credentials)
+        org = user.get('o')
+        role = user.get('r')
+        requests.org = org
+        requests.role = role
+        requests.token = token
+    except Exception as e:
+        print(e)
+        raise HTTPException(
+            status_code=status.HTTP_401_UNAUTHORIZED,
+            detail="Invalid JWT",
+        )
\ No newline at end of file
